
# LECA Bash library
#
# The LECA bash library provides a set of function used for helping
# development of bash script mainly to write job script on the luke
# cluster
#
# The files from the LECA Bash library must be sourced from your main script
#
#
# Provides function for manipulating a stack of values
# ====================================================
#
# Provides function:
#
#    - newstack <STACKNAME>
#      Creates a new stack named STACKNAME
#
#    - stacksize <STACKNAME>
#      Returns the count of element stored in the stack
#
#    - pushvalue <STACKNAME> <VALUE>
#      Adds the value VALUE at the end of the stack STACKNAME
#
#    - popvalue <STACKNAME>
#      Pops out the last pushed value of the stack.
#      If the stack is already empty the function returns nothing
#      and the return status is set to 1 instead of 0 usually
#

include logging
logdebug "Load stacks package"


function newstack() {
  eval declare -a "${1}"
}

function stacksize() {
  eval "echo \${#${1}[@]}"
}

function pushvalue() {
  p="${1}[$(stacksize ${1})]=\"${2}\""
  eval "$p"
}

function popvalue() {
  local STACK="${1}"
  shift

  if [[ ! -z "${1}" ]]; then
    COMMAND="${1}="
  else
    COMMAND="echo "
  fi

  local s=$(stacksize ${STACK})
  if (( s==0 )); then
    return 1
  fi

  local valcmd="${COMMAND}\${${STACK}[\$(( s - 1 ))]}"
  eval $valcmd
  valcmd="unset ${STACK}[\$(( s - 1 ))]"
  eval $valcmd
  return 0
}
