# LECA Bash library
#
# The LECA bash library provides a set of function used for helping
# development of bash script mainly to write job script on the luke
# cluster
#
# The files from the LECA Bash library must be sourced from your main script
#
#


if [[ -z "${LECALIB_UTIL_SH}" ]]; then
	LECALIB_UTIL_SH=1
	LECABASHLIB_RELOADING=0

	THIS_DIR="$(dirname ${BASH_SOURCE[0]})"

    source "${THIS_DIR}/utils.sh"

	function abspath() {
		local P=$1
		echo "$(cd "$(dirname "${P}")" && pwd -P)/$(basename "${P}")"
	}

	LECALIB_DIR=$(abspath "${THIS_DIR}")

	function upper() {
		echo $1 | tr "a-z" "A-Z"
	}

	function lower() {
		echo $1 | tr "A-Z" "a-z"
	}

	function indirect() {
		eval echo \$${1}
	}

  function include() {
		local MODULE=$(upper $1)
		local LOADED_MODULE_VAR="LECALIB_${MODULE}_SH"
		local LOADED_MODULE=$(indirect $LOADED_MODULE_VAR)
		if [[ -z "${LOADED_MODULE}" || "$LECABASHLIB_RELOADING" == 1 ]]; then
			source "${LECALIB_DIR}/${1}.sh"
			eval $LOADED_MODULE_VAR=1
			if (( LECABASHLIB_RELOADING == 1 )) ; then
				loginfo "Module $1 reloaded..."
			fi
		fi
	}

	function reload() {
		LECABASHLIB_RELOADING=1
		include "${1}"
		LECABASHLIB_RELOADING=0
	}


	function onluke() {
		[[ $(hostname | sed -E 's/^(....).*$/\1/') == "luke" ]]
	}

	function onfroggy() {
		[[ $(hostname | sed -E 's/^(....).*$/\1/') == "frog" ]]
	}

fi
